==> cloud-5.0.0-rc2.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/constant/templates/form/openstack/network.ts <==
import EntityFormTemplate from 'model/EntityFormTemplate';

const OPENSTACK_NETWORK_TEMPLATE: EntityFormTemplate[] = [
  {
    cloudServiceProvider: 'openstack',
    entityName: 'network',
    actionType: 'create',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Network',
        keyValueRecords: [
          { type: 'default', labelName: 'Name', name: 'name', defaultValue: '', required: true },
          { type: 'boolean', labelName: 'Admin state up', name: 'admin_state_up', defaultValue: true },
          { type: 'boolean', labelName: 'Shared', name: 'shared', defaultValue: false },
          { type: 'boolean', labelName: 'External Network', name: 'external', defaultValue: false },
          { type: 'multi-select', labelName: 'Availability Zone', name: 'availability_zone',
            url: '/cloud_dashboard/openstack/{cloud_context}/availability_zones',
            defaultValue: []
          }
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'network',
    actionType: 'edit',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Network',
        keyValueRecords: [
          { type: 'default', labelName: 'Name', name: 'name', defaultValue: '', required: true },
          { type: 'boolean', labelName: 'Admin state up', name: 'admin_state_up', defaultValue: true },
          { type: 'boolean', labelName: 'Shared', name: 'shared', defaultValue: false },
          { type: 'boolean', labelName: 'External Network', name: 'external', defaultValue: false },
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'network',
    actionType: 'delete',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to delete the {{entityName}} {{name}}?'
      },
    ],
    submitButtonLabel: 'Delete'
  },
]

export default OPENSTACK_NETWORK_TEMPLATE;

==> cloud-5.1.0.tar.gz: cloud/modules/cloud_dashboard/cloud_dashboard/src/constant/templates/form/openstack/network.ts <==
import EntityFormTemplate from 'model/EntityFormTemplate';

const OPENSTACK_NETWORK_TEMPLATE: EntityFormTemplate[] = [
  {
    cloudServiceProvider: 'openstack',
    entityName: 'network',
    actionType: 'create',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Network',
        keyValueRecords: [
          { type: 'default', labelName: 'Name', name: 'name', defaultValue: '', required: true },
          { type: 'boolean', labelName: 'Admin state up', name: 'admin_state_up', defaultValue: true },
          { type: 'boolean', labelName: 'Shared', name: 'shared', defaultValue: false },
          { type: 'boolean', labelName: 'External network', name: 'external', defaultValue: false },
          { type: 'multi-select', labelName: 'Availability Zone', name: 'availability_zone',
            url: '/cloud_dashboard/openstack/{cloud_context}/availability_zones?component_name=network&zone_resource=network',
            defaultValue: []
          }
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'network',
    actionType: 'edit',
    entityRecords: [
      {
        type: 'panel',
        panelName: 'Network',
        keyValueRecords: [
          { type: 'default', labelName: 'Name', name: 'name', defaultValue: '', required: true },
          { type: 'boolean', labelName: 'Admin state up', name: 'admin_state_up', defaultValue: true },
          { type: 'boolean', labelName: 'Shared', name: 'shared', defaultValue: false },
          { type: 'boolean', labelName: 'External network', name: 'external', defaultValue: false },
        ]
      }
    ]
  },
  {
    cloudServiceProvider: 'openstack',
    entityName: 'network',
    actionType: 'delete',
    entityRecords: [
      {
        type: 'label',
        text: 'Are you sure you want to delete the {{entityName}} {{name}}?'
      },
    ],
    submitButtonLabel: 'Delete'
  },
]

export default OPENSTACK_NETWORK_TEMPLATE;
